| exportCSV | R Documentation |
Export pptxList file to desired format
exportCSV(
file,
format = "HTML",
rawDataName = NULL,
rawDataFile = "rawData.RDS"
)
file |
The name of the file which the data are to be read from. |
format |
desired output format. Possible choices are one of the c("HTML","pdf","word","pptx","plotzip") |
rawDataName |
The name of the rawData |
rawDataFile |
The name of the rawData file which the data are to be read from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.